#!/bin/bash

# This helper script will handle deploying a kinesis firehose stream to s3

set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access "${appsNamespace}" configmaps
check_access "${infraNamespace}" configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

# Set s3 destination ARN
echo "Found ARN for s3 destination: \"${DESTINATION_ARN}\""
echo "destination_bucket_arn=\"${DESTINATION_ARN}\"" >> "${tfAdditionalVarsFile}"

if [ ! -z "${SOURCE_ARN}" ]; then
# Set Kinesis source ARN
echo "Found ARN for Kinesis source: \"${SOURCE_ARN}\""
echo "source_kinesis_arn=\"${SOURCE_ARN}\"" >> "${tfAdditionalVarsFile}"
else
echo "NO ARN for Kinesis source found! Firehose source will be set to Direct PUT"
fi

if [ ! -z "${GLUE_DATABASE_NAME}" ]; then
echo "Found Glue Dabatase name : \"${GLUE_DATABASE_NAME}\""
echo "schema_configuration_database_name=\"${GLUE_DATABASE_NAME}\"" >> "${tfAdditionalVarsFile}"
fi

if [ ! -z "${GLUE_ROLE_ARN}" ]; then
echo "Found Glue role ARN  : \"${GLUE_ROLE_ARN}\""
echo "schema_configuration_role_arn=\"${GLUE_ROLE_ARN}\"" >> "${tfAdditionalVarsFile}"
fi

if [ ! -z "${LAMBDA_PROCESSOR_ARN}" ]; then
echo "Found Lambda Processor ARN  : \"${LAMBDA_PROCESSOR_ARN}\""
echo "lambda_processor_arn=\"${LAMBDA_PROCESSOR_ARN}\"" >> "${tfAdditionalVarsFile}"
echo "lambda_version=\"${LAMBDA_VERSION}\"" >> "${tfAdditionalVarsFile}"
fi

# Set Kinesis source ARN
echo "Found ARN for IAM role: \"${ROLE_ARN}\""
echo "iam_role_arn=\"${ROLE_ARN}\"" >> "${tfAdditionalVarsFile}"

# Show additional .auto.tfvars file
print_header "Show additional_settings.auto.tfvars"
cat "$tfAdditionalVarsFile"

## == Terraform Plan & Apply ==
terraform_init
terraform_plan
terraform_apply
terraform_output

## == Output values to ConfigMap ==
print_header "Dump output to ConfigMap"

arnConfigMapName=${namingPrefix}-arn

terraform_get name nameValue
terraform_get id idValue
terraform_get arn arnValue
terraform_get source_kinesis_arn sourceArn
terraform_get destination_bucket_arn destination
terraform_get firehose-put-records-policy putRecordPolicy

sourceArn=${sourceArn:="direct-put"}

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  NAME: ${nameValue}
  ID: ${idValue}
  ARN: ${arnValue}
  SOURCE: ${sourceArn}
  DESTINATION: ${destination}
  PutRecordPolicy: ${putRecordPolicy}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
